@@ -25,7 +25,6 @@ from debian.deb822 import Deb822
 
 from debputy import DEBPUTY_DOC_ROOT_DIR
 from debputy.architecture_support import dpkg_architecture_table
-from debputy.commands.debputy_cmd.output import OutputStylingBase
 from debputy.deb_packaging_support import dpkg_field_list_pkg_dep
 from debputy.dh.debhelper_emulation import (
     dhe_filedoublearray,
@@ -203,7 +202,6 @@ UNSUPPORTED_DH_CONFIGS_AND_TOOLS_FOR_ZZ_DEBPUTY = [
     UnsupportedDHConfig(
         "user.timer", "dh_installsystemduser", bug_950723_prefix_matching=True
     ),
-    UnsupportedDHConfig("udev", "dh_installudev"),
     UnsupportedDHConfig("menu", "dh_installmenu"),
     UnsupportedDHConfig("menu-method", "dh_installmenu"),
     UnsupportedDHConfig("ucf", "dh_ucf"),
@@ -216,7 +214,7 @@ UNSUPPORTED_DH_CONFIGS_AND_TOOLS_FOR_ZZ_DEBPUTY = [
     UnsupportedDHConfig("menutest", "dh_installdeb"),
     UnsupportedDHConfig("isinstallable", "dh_installdeb"),
 ]
-SUPPORTED_DH_ADDONS = frozenset(
+SUPPORTED_DH_ADDONS_WITH_ZZ_DEBPUTY = frozenset(
     {
         # debputy's own
         "debputy",
@@ -225,8 +223,10 @@ SUPPORTED_DH_ADDONS = frozenset(
         "single-binary",
     }
 )
-DH_ADDONS_TO_REMOVE = frozenset(
+DH_ADDONS_TO_REMOVE_FOR_ZZ_DEBPUTY = frozenset(
     [
+        # The `zz-debputy` add-on replaces the `zz-debputy-rrr` plugin.
+        "zz-debputy-rrr",
         # Sequences debputy directly replaces
         "dwz",
         "elf-tools",
@@ -1691,7 +1691,7 @@ def detect_dh_addons_with_zz_integration(
     )
     saw_zz_debputy = "zz-debputy" in remaining_sequences
     must_use_zz_debputy = False
-    remaining_sequences -= SUPPORTED_DH_ADDONS
+    remaining_sequences -= SUPPORTED_DH_ADDONS_WITH_ZZ_DEBPUTY
     for sequence in remaining_sequences & DH_ADDONS_TO_PLUGINS.keys():
         migration = DH_ADDONS_TO_PLUGINS[sequence]
         feature_migration.require_plugin(migration.debputy_plugin)
@@ -1712,7 +1712,7 @@ def detect_dh_addons_with_zz_integration(
     remaining_sequences -= DH_ADDONS_TO_PLUGINS.keys()
 
     alt_key = "unsupported-dh-sequences"
-    for sequence in remaining_sequences & DH_ADDONS_TO_REMOVE:
+    for sequence in remaining_sequences & DH_ADDONS_TO_REMOVE_FOR_ZZ_DEBPUTY:
         if sequence in bd_sequences:
             feature_migration.warn(
                 f"TODO: MANUAL MIGRATION - Remove build dependency on dh-sequence-{sequence}"
@@ -1722,7 +1722,7 @@ def detect_dh_addons_with_zz_integration(
                 f"TODO: MANUAL MIGRATION - Remove --with {sequence} from dh in d/rules"
             )
 
-    remaining_sequences -= DH_ADDONS_TO_REMOVE
+    remaining_sequences -= DH_ADDONS_TO_REMOVE_FOR_ZZ_DEBPUTY
 
     for sequence in remaining_sequences:
         key = f"unsupported-dh-sequence-{sequence}"
